@@ -3,7 +3,7 @@ from logging import Logger
 from supbot.app_driver import AppDriver
 from supbot.system import System
 
-logger: Logger = None
+logger: Logger
 kwargs = None
-system: System = None
-driver: AppDriver = None
+system: System
+driver: AppDriver
