@@ -23,23 +23,21 @@ def goto_chat_fallback(_current: GUIState, _to: GUIState) -> Tuple[GotoStateResu
         if result == GotoStateResult.SUCCESS:
             return result, new_current
         elif result == GotoStateResult.ELEMENT_NOT_FOUND:
+            contact = cast(ChatState, _to).contact
+            if not re.search("\d{11,13}", contact):
+                return result, new_current
 
             result, new_current = goto_state(new_current, temp_group)
 
             if result == GotoStateResult.SUCCESS:
-                contact = cast(ChatState, _to).contact
-                if re.search("\d{11,13}", contact):
-                    if g.driver.type_and_send(f"wa.me/{contact}") and g.driver.click_on_last_chat_link():
-                        if not g.driver.click_ok():
-                            return GotoStateResult.SUCCESS, _to
+                if g.driver.type_and_send(f"wa.me/{contact}") and g.driver.click_on_last_chat_link():
+                    if not g.driver.click_ok():
+                        return GotoStateResult.SUCCESS, _to
 
     return result, new_current
 
 
 def goto_state(_current: GUIState, _to: GUIState) -> Tuple[GotoStateResult, GUIState]:
-    if _current == _to:
-        return GotoStateResult.SUCCESS, _to
-
     result, new_current = _step_to_state(_current, _to)
 
     if result == GotoStateResult.CHECK_FAILED:
